@@ -2,6 +2,7 @@ use crate::in_model::class::subclasses::Subclasses as In;
 use crate::out_model::class::feature::Feature;
 use crate::out_model::class::subclass::Subclass;
 use crate::out_model::class::subclasses::Subclasses as Out;
+use crate::text_utils::proper_noun;
 
 impl In {
     pub fn out(self, class_name: &str) -> (Out, Feature) {
@@ -13,7 +14,7 @@ impl In {
             entries,
             features,
         } = self;
-        let entries: Vec<Subclass> = entries.into_iter().map(|x| x.into()).collect();
+        let entries: Vec<Subclass> = entries.into_iter().map(|x| (x, level).into()).collect();
         let f = Feature {
             name: name.to_string(),
             level,
@@ -22,7 +23,7 @@ impl In {
                 prefix,
                 entries
                     .iter()
-                    .map(|x| format!(". [[{}.{}]]\r\n", class_name, x.name))
+                    .map(|x| format!(". [[{}={}.{}]]\r\n", proper_noun(&x.name), class_name, x.name))
                     .collect::<String>(),
                 postfix
             ),
@@ -37,4 +38,4 @@ impl In {
             f,
         )
     }
-}
\ No newline at end of file
+}
